==> 0.1.15.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/ReachableDeviceUnlockerListener.java <==
package com.medipreco.loopboxplugin;

import android.annotation.TargetApi;
import android.os.Build;
import android.util.Base64;
import br.com.loopkey.indigo.lklib.commands.LKCommand;
import br.com.loopkey.indigo.lklib.commands.LKCommandRepository;
import br.com.loopkey.indigo.lklib.commands.LKDeviceCommunicator;
import br.com.loopkey.indigo.lklib.commands.implementations.LKUnlockCommand;
import br.com.loopkey.indigo.lklib.core.LKReachableDevice;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceListener;
import br.com.loopkey.indigo.lklib.entity.LKCommDevice;
import br.com.loopkey.indigo.lklib.entity.LKEntity;

import java.util.List;

public class ReachableDeviceUnlockerListener implements LKReachableDeviceListener {

  private LKReachableDevice reachableDevice;

  public ReachableDeviceUnlockerListener(LKReachableDevice reachableDevice) {
    this.reachableDevice = reachableDevice;
  }

  @Override
  public void onReachableDevices(List<LKEntity> reachedDevices) {
    for (LKEntity reachedDevice: reachedDevices) {

      LKCommand unlockCommand = createUnlockCommand();
      sendUnlockCommand(reachedDevice, unlockCommand);
      unsubscribeListener(this);
    }
  }

  private LKCommand createUnlockCommand() {
    LKUnlockCommand.Listener loopBoxUnlockListener = new UnlockCommand();
    return LKCommandRepository.createUnlockCommand(loopBoxUnlockListener);
  }

  @TargetApi(Build.VERSION_CODES.FROYO)
  private LKCommDevice createDevice(LKEntity reachedDevice) {
    LKCommDevice device = new LKCommDevice("WtSwACAABAAdwQ==".getBytes());
    device.id = 1;
    device.kind =  "multiple".toUpperCase();
    device.key = Base64.decode("4KNZXmgCzFNlygTgoxcjeGCLKF2bLbIZrhig4qDNG/o=", 0);
    device.commandData = Base64.decode("CAEC", 0);
    device.unlockDuration = 1000;
    device.rollCount = reachedDevice.getRollCount();

    return device;
  }

  private void sendUnlockCommand(LKEntity reachedDevice, LKCommand unlockCommand) {
    LKCommDevice device = createDevice(reachedDevice);
    LKDeviceCommunicator deviceCommunicator = reachableDevice
        .deviceCommunicatorForDevice(device, 0);
//    deviceCommunicator.setCloseConnectionAfterResponse(true);
    deviceCommunicator.execute(unlockCommand);
  }

  private void unsubscribeListener(LKReachableDeviceListener listener) {
    reachableDevice.unsubscribe(this);
  }
}

==> 0.1.17.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/ReachableDeviceUnlockerListener.java <==
package com.medipreco.loopboxplugin;

import android.annotation.TargetApi;
import android.os.Build;
import android.util.Base64;
import android.util.Log;
import br.com.loopkey.indigo.lklib.commands.LKCommand;
import br.com.loopkey.indigo.lklib.commands.LKCommandRepository;
import br.com.loopkey.indigo.lklib.commands.LKDeviceCommunicator;
import br.com.loopkey.indigo.lklib.commands.implementations.LKUnlockCommand;
import br.com.loopkey.indigo.lklib.core.LKReachableDevice;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceListener;
import br.com.loopkey.indigo.lklib.entity.LKCommDevice;
import br.com.loopkey.indigo.lklib.entity.LKEntity;

import java.util.List;

public class ReachableDeviceUnlockerListener implements LKReachableDeviceListener {

  private LKReachableDevice reachableDevice;
  private UnlockData unlockData;

  public ReachableDeviceUnlockerListener(LKReachableDevice reachableDevice, UnlockData unlockData) {
    this.reachableDevice = reachableDevice;
    this.unlockData = unlockData;
  }

  @Override
  public void onReachableDevices(List<LKEntity> reachedDevices) {
    for (LKEntity reachedDevice: reachedDevices) {

      LKCommand unlockCommand = createUnlockCommand();
      sendUnlockCommand(reachedDevice, unlockCommand);
      unsubscribeListener(this);
    }
  }

  private LKCommand createUnlockCommand() {
    LKUnlockCommand.Listener loopBoxUnlockListener = new UnlockCommand();
    return LKCommandRepository.createUnlockCommand(loopBoxUnlockListener);
  }

  @TargetApi(Build.VERSION_CODES.FROYO)
  private LKCommDevice createDevice(LKEntity reachedDevice) {
    Log.d("LoopboxP", "Creating device: " + this.unlockData);
    LKCommDevice device = new LKCommDevice(reachedDevice.getSerialCode());

    device.id = new Integer(this.unlockData.getId());
    device.kind =  this.unlockData.getKind().toUpperCase();
    device.key = Base64.decode(this.unlockData.getKey(), 0);
    device.commandData = Base64.decode(this.unlockData.getCommandData(), 0);
    device.unlockDuration = 1000;
    device.rollCount = reachedDevice.getRollCount();

    return device;
  }

  private void sendUnlockCommand(LKEntity reachedDevice, LKCommand unlockCommand) {
    LKCommDevice device = createDevice(reachedDevice);
    Log.d("LoopboxP", "Sending unlock command");
    LKDeviceCommunicator deviceCommunicator = reachableDevice
        .deviceCommunicatorForDevice(device, 0);
//    deviceCommunicator.setCloseConnectionAfterResponse(true);
    deviceCommunicator.execute(unlockCommand);
  }

  private void unsubscribeListener(LKReachableDeviceListener listener) {
    reachableDevice.unsubscribe(this);
  }
}
